==> php54-owncloud-7.0.4.tgz: share/owncloud/apps/calendar/l10n/lt_LT.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ne visi kalendoriai pilnai kešuoti",
"Everything seems to be completely cached" => "Viskas, atrodo, yra pilnai kešuota",
"No calendars found." => "Kalendorių nerasta.",
"No events found." => "Įvykių nerasta.",
"Wrong calendar" => "Ne tas kalendorius",
"You do not have the permissions to edit this event." => "Jūs neturite leidimo redaguoti šį įvykį.",
"The file contained either no events or all events are already saved in your calendar." => "Dokumente arba nebuvo įvykių, arba visi jame buvę įvykiai jau buvo jūsų kalendoriuje.",
"Import failed" => "importuoti nepavyko",
"New Timezone:" => "Nauja laiko juosta:",
"Timezone changed" => "Laiko zona pakeista",
"Invalid request" => "Klaidinga užklausa",
"Calendar" => "Kalendorius",
"Deletion failed" => "Ištrinti nepavyko",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "grupė",
"can edit" => "gali redaguoti",
"can share" => "gali dalintis",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Sekmadienis",
"Monday" => "Pirmadienis",
"Tuesday" => "Antradienis",
"Wednesday" => "Trečiadienis",
"Thursday" => "Ketvirtadienis",
"Friday" => "Penktadienis",
"Saturday" => "Šeštadienis",
"Sun." => "Sk.",
"Mon." => "Pr.",
"Tue." => "An.",
"Wed." => "Tr.",
"Thu." => "Kt.",
"Fri." => "Pn.",
"Sat." => "Št.",
"January" => "Sausis",
"February" => "Vasaris",
"March" => "Kovas",
"April" => "Balandis",
"May" => "Gegužė",
"June" => "Birželis",
"July" => "Liepa",
"August" => "Rugpjūtis",
"September" => "Rugsėjis",
"October" => "Spalis",
"November" => "Lapkritis",
"December" => "Gruodis",
"Jan." => "Sau.",
"Feb." => "Vas.",
"Mar." => "Kov.",
"Apr." => "Bal.",
"May." => "Geg.",
"Jun." => "Bir.",
"Jul." => "Lie.",
"Aug." => "Rugp.",
"Sep." => "Rugs.",
"Oct." => "Spa.",
"Nov." => "Lap.",
"Dec." => "Groud.",
"All day" => "Visa diena",
"New Calendar" => "Naujas kalendorius",
"Missing or invalid fields" => "Trūksta būtinos informacijos",
"Title" => "Pavadinimas",
"From Date" => "Nuo datos",
"From Time" => "Nuo laiko",
"To Date" => "Iki datos",
"To Time" => "Iki laiko",
"The event ends before it starts" => "Įvykis baigiasi anksčiau nei jis prasideda",
"There was a database fail" => "Įvyko duomenų bazės klaida",
"Birthday" => "Gimtadienis",
"Business" => "Verslas",
"Call" => "Skambučiai",
"Clients" => "Klientai",
"Deliverer" => "Vykdytojas",
"Holidays" => "Išeiginės",
"Ideas" => "Idėjos",
"Journey" => "Kelionė",
"Jubilee" => "Jubiliejus",
"Meeting" => "Susitikimas",
"Other" => "Kiti",
"Personal" => "Asmeniniai",
"Projects" => "Projektai",
"Questions" => "Klausimai",
"Work" => "Darbas",
"by" => " ",
"unnamed" => "be pavadinimo",
"You do not have the permissions to update this calendar." => "Jūs neturite leidimo atnaujinti šį kalendorių.",
"You do not have the permissions to delete this calendar." => "Jūs neturite leidimo ištrinti šį kalendorių.",
"You do not have the permissions to add to this calendar." => "Jūs neturite leidimo prijungti prie šio kalendoriaus.",
"You do not have the permissions to add events to this calendar." => "Jūs neturite leidimo pridėti įvykių į šį kalendorių.",
"You cannot add non-public events to a shared calendar." => "Negalite pridėti ne viešų įvykių į paviešintą kalendorių.",
"You do not have the permissions to delete this event." => "Jūs neturite leidimo ištrinti šį įvykį.",
"Busy" => "Užimtas",
"Show full event" => "Rodyti pilną įvykį",
"Show only busy" => "Rodyti tik užimtus",
"Hide event" => "PAslėpti įvykį",
"Does not repeat" => "Nekartoti",
"Daily" => "Kasdien",
"Weekly" => "Kiekvieną savaitę",
"Every Weekday" => "Kiekvieną savaitės dieną",
"Bi-Weekly" => "Kas dvi savaites",
"Monthly" => "Kiekvieną mėnesį",
"Yearly" => "Kiekvienais metais",
"never" => "niekada",
"by occurrences" => "pagal įvykius",
"by date" => "pagal datą",
"by monthday" => "pagal mėnesio dieną",
"by weekday" => "pagal savaitės dieną",
"events week of month" => "menėsio įvykių savaitė",
"first" => "pirmas",
"second" => "antras",
"third" => "trečias",
"fourth" => "ketvirtas",
"fifth" => "penktas",
"last" => "paskutinis",
"by events date" => "pagal įvykių datą",
"by yearday(s)" => "pagal metų diena(s)",
"by weeknumber(s)" => "pagal savaitę(es)",
"by day and month" => "pagal dieną ir mėnesį",
"Contact birthdays" => "Kontaktų gimtadieniai",
"Date" => "Data",
"Cal." => "Kal.",
"Day" => "Diena",
"Week" => "Savaitė",
"Month" => "Mėnuo",
"Today" => "Šiandien",
"CalDav Link" => "CalDav adresas",
"Timezone" => "Laiko juosta",
"Update timezone automatically" => "Atnaujinti laiko zoną automatiškai",
"Time format" => "Laiko formatas",
"24h" => "24val",
"12h" => "12val",
"Start week on" => "Savaitę pradėti nuo",
"Cache" => "Kešavimas",
"Clear cache for repeating events" => "Išvalyti kešuotus ir pasikartojančius įvykius",
"Share Calendar" => "Dalintis kalendoriumi",
"Download" => "Atsisiųsti",
"Edit" => "Keisti",
"Delete" => "Trinti",
"New calendar" => "Naujas kalendorius",
"Edit calendar" => "Taisyti kalendorių",
"Edit event" => "Redaguoti įvykį",
"Save event" => "Išsaugoti įvykį",
"Delete event" => "Ištrinti įvykį",
"Eventinfo" => "Informacija",
"Repeating" => "Pasikartojimas",
"Alarm" => "Priminimas",
"Attendees" => "Dalyviai",
"Share" => "Dalintis",
"Title of the Event" => "Įvykio pavadinimas",
"from" => "iš",
"to" => "į",
"All Day Event" => "Visos dienos įvykis",
"Advanced options" => "Papildomi nustatymai",
"Location" => "Vieta",
"Categories (separate by comma)" => "Kategorijos (atskirtos kableliais)",
"Edit categories" => "Redaguoti kategorijas",
"Description" => "Aprašymas",
"Export event" => "Eksportuoti įvykį",
"Repeat" => "Kartoti",
"Advanced" => "Išplėstiniai",
"Select weekdays" => "Pasirinkite savaitės dienas",
"Select days" => "Pasirinkite dienas",
"and the events day of year." => "ir metų įvykių diena.",
"and the events day of month." => "ir menėsio įvykių diena.",
"Select months" => "Pasirinkite mėnesius",
"Select weeks" => "Pasirinkite savaites",
"and the events week of year." => "ir metų įvykių savaitė",
"Interval" => "Intervalas",
"End" => "Pabaiga",
"occurrences" => "įvykiai",
"Visibility to people shared with" => "Matomumas asmenų su kuriais pasidalinta",
"create a new calendar" => "sukurti naują kalendorių",
"Import a calendar file" => "Importuoti kalendoriaus failą",
"Please choose a calendar" => "Pasirinkite kalendorių",
"Name of new calendar" => "Naujo kalendoriaus pavadinimas",
"Take an available name!" => "Pasirinkite neužimtą pavadinimą!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendorius tokiu pavadinimu jau egzistuoja. Jei tęsite toliau, šie kalendoriai bus sujungti.",
"Remove all events from the selected calendar" => "Ištrinti visus įvykius iš pasirinkto kalendoriaus",
"Import" => "Importuoti",
"Close Dialog" => "Uždaryti",
"Create a new event" => "Sukurti naują įvykį",
"Create event" => "Sukurti įvykį",
"Share with user or group" => "Dalintis su vartotoju arba grupe",
"Unshare" => "Nebesidalinti",
"Not shared with anyone" => "Nepasidalinta su niekuo",
"Send Email" => "Siųsti el. laišką",
"Shared via calendar" => "Dalintis per kalendorių",
"Not shared with anyone via calendar" => "Nepasidalinta su niekuo per kalendorių",
"View an event" => "Peržiūrėti įvykį",
"Category" => "Kategorija",
"No categories selected" => "Nepasirinktos jokios katagorijos",
"Access Class" => "Priėjimo klasė",
"From" => "Nuo",
"at" => " ",
"To" => "Iki"
);

==> php54-owncloud-8.0.2.tgz: share/owncloud/apps/calendar/l10n/lt_LT.php <==
<?php
$TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ne visi kalendoriai pilnai kešuoti",
"Everything seems to be completely cached" => "Viskas, atrodo, yra pilnai kešuota",
"No calendars found." => "Kalendorių nerasta.",
"No events found." => "Įvykių nerasta.",
"Wrong calendar" => "Ne tas kalendorius",
"You do not have the permissions to edit this event." => "Jūs neturite leidimo redaguoti šį įvykį.",
"The file contained either no events or all events are already saved in your calendar." => "Dokumente arba nebuvo įvykių, arba visi jame buvę įvykiai jau buvo jūsų kalendoriuje.",
"events have been saved in the new calendar" => "įvykiai buvo išsaugoti naujame kalendoriuje",
"Import failed" => "importuoti nepavyko",
"events have been saved in your calendar" => "įvykiai buvo išsaugoti tavo kalendoriuje",
"New Timezone:" => "Nauja laiko juosta:",
"Timezone changed" => "Laiko zona pakeista",
"Invalid request" => "Klaidinga užklausa",
"Calendar" => "Kalendorius",
"Error sending mail" => "Klaida siunčiant laišką",
"Deletion failed" => "Ištrinti nepavyko",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"Do you really want to delete this calendar?" => "Ar tikrai nori ištrinti šį kalendorių?",
"group" => "grupė",
"can edit" => "gali redaguoti",
"can share" => "gali dalintis",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Sekmadienis",
"Monday" => "Pirmadienis",
"Tuesday" => "Antradienis",
"Wednesday" => "Trečiadienis",
"Thursday" => "Ketvirtadienis",
"Friday" => "Penktadienis",
"Saturday" => "Šeštadienis",
"Sun." => "Sk.",
"Mon." => "Pr.",
"Tue." => "An.",
"Wed." => "Tr.",
"Thu." => "Kt.",
"Fri." => "Pn.",
"Sat." => "Št.",
"January" => "Sausis",
"February" => "Vasaris",
"March" => "Kovas",
"April" => "Balandis",
"May" => "Gegužė",
"June" => "Birželis",
"July" => "Liepa",
"August" => "Rugpjūtis",
"September" => "Rugsėjis",
"October" => "Spalis",
"November" => "Lapkritis",
"December" => "Gruodis",
"Jan." => "Sau.",
"Feb." => "Vas.",
"Mar." => "Kov.",
"Apr." => "Bal.",
"May." => "Geg.",
"Jun." => "Bir.",
"Jul." => "Lie.",
"Aug." => "Rugp.",
"Sep." => "Rugs.",
"Oct." => "Spa.",
"Nov." => "Lap.",
"Dec." => "Groud.",
"All day" => "Visa diena",
"New Calendar" => "Naujas kalendorius",
"Missing or invalid fields" => "Trūksta būtinos informacijos",
"Title" => "Pavadinimas",
"From Date" => "Nuo datos",
"From Time" => "Nuo laiko",
"To Date" => "Iki datos",
"To Time" => "Iki laiko",
"The event ends before it starts" => "Įvykis baigiasi anksčiau nei jis prasideda",
"There was a database fail" => "Įvyko duomenų bazės klaida",
"Interval is not valid. It must be a positive integer!" => "Intervalas netinkamas. Turi būti teigiamas sveikas skaičius!",
"Birthday" => "Gimtadienis",
"Business" => "Verslas",
"Call" => "Skambučiai",
"Clients" => "Klientai",
"Deliverer" => "Vykdytojas",
"Holidays" => "Išeiginės",
"Ideas" => "Idėjos",
"Journey" => "Kelionė",
"Jubilee" => "Jubiliejus",
"Meeting" => "Susitikimas",
"Other" => "Kiti",
"Personal" => "Asmeniniai",
"Projects" => "Projektai",
"Questions" => "Klausimai",
"Work" => "Darbas",
"by" => " ",
"unnamed" => "be pavadinimo",
"You do not have the permissions to update this calendar." => "Jūs neturite leidimo atnaujinti šį kalendorių.",
"You do not have the permissions to delete this calendar." => "Jūs neturite leidimo ištrinti šį kalendorių.",
"You do not have the permissions to add to this calendar." => "Jūs neturite leidimo prijungti prie šio kalendoriaus.",
"You do not have the permissions to add events to this calendar." => "Jūs neturite leidimo pridėti įvykių į šį kalendorių.",
"You cannot add non-public events to a shared calendar." => "Negalite pridėti ne viešų įvykių į paviešintą kalendorių.",
"You do not have the permissions to delete this event." => "Jūs neturite leidimo ištrinti šį įvykį.",
"Busy" => "Užimtas",
"Show full event" => "Rodyti pilną įvykį",
"Show only busy" => "Rodyti tik užimtus",
"Hide event" => "PAslėpti įvykį",
"Does not repeat" => "Nekartoti",
"Daily" => "Kasdien",
"Weekly" => "Kiekvieną savaitę",
"Every Weekday" => "Kiekvieną savaitės dieną",
"Bi-Weekly" => "Kas dvi savaites",
"Monthly" => "Kiekvieną mėnesį",
"Yearly" => "Kiekvienais metais",
"never" => "niekada",
"by occurrences" => "pagal įvykius",
"by date" => "pagal datą",
"by monthday" => "pagal mėnesio dieną",
"by weekday" => "pagal savaitės dieną",
"events week of month" => "menėsio įvykių savaitė",
"first" => "pirmas",
"second" => "antras",
"third" => "trečias",
"fourth" => "ketvirtas",
"fifth" => "penktas",
"last" => "paskutinis",
"by events date" => "pagal įvykių datą",
"by yearday(s)" => "pagal metų diena(s)",
"by weeknumber(s)" => "pagal savaitę(es)",
"by day and month" => "pagal dieną ir mėnesį",
"Contact birthdays" => "Kontaktų gimtadieniai",
"Date" => "Data",
"Day" => "Diena",
"Week" => "Savaitė",
"Month" => "Mėnuo",
"Today" => "Šiandien",
"CalDav Link" => "CalDav adresas",
"Timezone" => "Laiko juosta",
"Update timezone automatically" => "Atnaujinti laiko zoną automatiškai",
"Time format" => "Laiko formatas",
"24h" => "24val",
"12h" => "12val",
"Start week on" => "Savaitę pradėti nuo",
"Cache" => "Kešavimas",
"Clear cache for repeating events" => "Išvalyti kešuotus ir pasikartojančius įvykius",
"Primary CalDAV address" => "Pirminis CalDAV adresas",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV adresas",
"Share Calendar" => "Dalintis kalendoriumi",
"Download" => "Atsisiųsti",
"Edit" => "Keisti",
"Delete" => "Trinti",
"New calendar" => "Naujas kalendorius",
"Edit calendar" => "Taisyti kalendorių",
"Edit event" => "Redaguoti įvykį",
"Save event" => "Išsaugoti įvykį",
"Delete event" => "Ištrinti įvykį",
"Eventinfo" => "Informacija",
"Repeating" => "Pasikartojimas",
"Alarm" => "Priminimas",
"Attendees" => "Dalyviai",
"Share" => "Dalintis",
"Title of the Event" => "Įvykio pavadinimas",
"from" => "iš",
"to" => "į",
"All Day Event" => "Visos dienos įvykis",
"Advanced options" => "Papildomi nustatymai",
"Location" => "Vieta",
"Categories (separate by comma)" => "Kategorijos (atskirtos kableliais)",
"Edit categories" => "Redaguoti kategorijas",
"Description" => "Aprašymas",
"Export event" => "Eksportuoti įvykį",
"Repeat" => "Kartoti",
"Advanced" => "Išplėstiniai",
"Select weekdays" => "Pasirinkite savaitės dienas",
"Select days" => "Pasirinkite dienas",
"and the events day of year." => "ir metų įvykių diena.",
"and the events day of month." => "ir menėsio įvykių diena.",
"Select months" => "Pasirinkite mėnesius",
"Select weeks" => "Pasirinkite savaites",
"and the events week of year." => "ir metų įvykių savaitė",
"Interval" => "Intervalas",
"End" => "Pabaiga",
"occurrences" => "įvykiai",
"Visibility to people shared with" => "Matomumas asmenų su kuriais pasidalinta",
"create a new calendar" => "sukurti naują kalendorių",
"Import a calendar file" => "Importuoti kalendoriaus failą",
"Please choose a calendar" => "Pasirinkite kalendorių",
"Name of new calendar" => "Naujo kalendoriaus pavadinimas",
"Take an available name!" => "Pasirinkite neužimtą pavadinimą!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendorius tokiu pavadinimu jau egzistuoja. Jei tęsite toliau, šie kalendoriai bus sujungti.",
"Remove all events from the selected calendar" => "Ištrinti visus įvykius iš pasirinkto kalendoriaus",
"Import" => "Importuoti",
"Close Dialog" => "Uždaryti",
"Create a new event" => "Sukurti naują įvykį",
"Create event" => "Sukurti įvykį",
"Share with user or group" => "Dalintis su vartotoju arba grupe",
"Unshare" => "Nebesidalinti",
"Not shared with anyone" => "Nepasidalinta su niekuo",
"Send Email" => "Siųsti el. laišką",
"Shared via calendar" => "Dalintis per kalendorių",
"Not shared with anyone via calendar" => "Nepasidalinta su niekuo per kalendorių",
"View an event" => "Peržiūrėti įvykį",
"Category" => "Kategorija",
"No categories selected" => "Nepasirinktos jokios katagorijos",
"%s of %s" => "%s iš %s",
"Access Class" => "Priėjimo klasė",
"From" => "Nuo",
"at" => " ",
"To" => "Iki"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);";
